import React, { useRef } from 'react'
import { Button, Card, Form, Input, Select } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
} from '@ant-design/pro-components'
import useBool from '@/utils/hooks/useBool'
import { useSearchParams, useNavigate } from 'react-router-dom'
import Page from '@/components/Page'
import { formItemLayout, tailFormItemLayout } from '@/utils/form'
import { postTaCustom, putTaCustom, getTaCustomId } from '@/services/taCustom'
const { Option } = Select

export default (props) => {
  const formRef = useRef()
  const [loading, startLoading, cancelLoading] = useBool()
  const [submiting, startSubmit, cancelSubmit] = useBool()

  const [searchParams] = useSearchParams()
  // const [form] = Form.useForm()
  const navigate = useNavigate()

  const id = searchParams.get('id')

  React.useEffect(() => {
    if (id) {
      getTaCustomId(id).then((res) => {
        formRef.current.setFieldsValue(res)
      })
    }
  })

  const onFinish = (values) => {
    startSubmit()
    if (id) {
      //修改
      putTaCustom(id, values)
        .then((res) => {
          cancelSubmit()
          navigate(-1)
        })
        .catch(() => {
          cancelSubmit()
        })
    } else {
      //新增
      postTaCustom(values)
        .then((res) => {
          cancelSubmit()
          navigate(-1)
        })
        .catch(() => {
          cancelSubmit()
        })
    }
  }

  return (
    <Page>
      <Card loading={loading}>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          submitter={{
            render: (_, doms) => [
              doms.find((dom) => dom.props?.children === '提交'),
              <Button onClick={() => navigate(-1)}>返回</Button>,
            ],
          }}
        >
          <ProFormText name="customName" label="客户公司" />
          <ProFormText name="dutyParagraph" label="客户税号" />
          <ProFormText name="openingBank" label="开户行" />
          <ProFormText name="account" label="客户账号" />
          <ProFormText name="contactsName" label="联系人姓名" />
          <ProFormText name="contactsTitle" label="联系人头衔" />
          <ProFormText name="contactsPhone" label="联系人手机" />
          <ProFormText name="contactsEmail" label="联系人邮箱" />
        </ProForm>
      </Card>
    </Page>
  )
}
