import React, { useEffect, useRef } from "react";
import {
  postTaProject,
  putTaProject,
  getTaProjectId,
} from "@/services/taProject";
import Page from "@/components/Page";
import { Button, Card } from "antd";
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
} from "@ant-design/pro-components";
import { useNavigate, useSearchParams } from "react-router-dom";
import moment from "moment";
export default (props) => {
  const formRef = useRef();
  const navigate = useNavigate();

  const [params] = useSearchParams();
  const id = params.get("id");

  useEffect(() => {
    if (id) {
      getTaProjectId(id).then((res) => {

        formRef.current?.setFieldsValue({
            ...res,
            time:[moment(res.startTime),moment(res.endTime)] 
        });
      });
    }
  }, []);
  const onFinish = (values) => {
    const data = {
      ...values,
      startTime: values.time[0],
      endTime: values.time[1],
    };
    console.log(data);
    if (!id) {
      postTaProject(data).then((res) => {
        navigate(-1);
      });
    } else if (id) {
      putTaProject(id, data).then((res) => {
        navigate(-1);
      });
    }
  };
  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          submitter={{
            render: (_, doms) => [
              doms.find((dom) => dom.props?.children === "提交"),
              <Button onClick={() => navigate(-1)}>返回</Button>,
            ],
          }}
        >
          <ProFormText name="partyA" label="甲方联系人" />
          <ProFormText name="partyAName" label="甲方名称" />
          <ProFormText name="partyB" label="乙方联系人" />
          <ProFormText name="partyBName" label="乙方名称" />
          <ProFormText name="projectName" label="项目名称" />
          <ProFormText name="introduction" label="项目简介" />
          <ProFormDateTimeRangePicker name="time" label="工作周期" />
          <ProFormMoney name="quotation" label="合同报价" />
          <ProFormMoney name="receivedMoney" label="已收款" />
          <ProFormMoney name="invoicedMoney" label="已开票额" />
          <ProFormText name="stageName" label="阶段名称" />
          <ProFormSelect name="status" label="状态" />
        </ProForm>
      </Card>
    </Page>
  );
};
