import List from '@/components/Page/List'
import React, { useRef } from 'react'
import { getTaProject, deleteTaProject } from '@/services/taProject'
import { Button } from 'antd'
import { ProFormDateTimeRangePicker } from '@ant-design/pro-components'
import { useNavigate } from 'react-router-dom'
import moment from 'moment'
export default (props) => {
  const navigate = useNavigate()

  const columns = [
    {
      title: '项目日期',
      dataIndex: 'startTime1',
      search: {
        transform: (value) => {
          return {
            startTime: value[0],
            endTime: value[1],
          }
        },
      },
      valueType: 'dateRange',
      // render: () => [<ProFormDateTimeRangePicker />],
      hideInTable: true,
    },

    {
      title: '甲方',
      dataIndex: 'partyA',
      search: false,
    },
    {
      title: '甲方名称',
      dataIndex: 'partyAName',
    },
    {
      title: '已方',
      dataIndex: 'partyB',
      search: false,
    },
    {
      title: '已方名称',
      dataIndex: 'partyBName',
    },

    {
      title: '项目名称',
      dataIndex: 'projectName',
    },
    {
      title: '项目简介',
      dataIndex: 'introduction',
      search: false,
    },

    {
      title: '开始日期',
      dataIndex: 'startTime',
      render: (t) => moment(t).format('YYYY-MM-DD'),
      search: false,
    },
    {
      title: '结束日期',
      dataIndex: 'endTime',
      render: (t) => moment(t).format('YYYY-MM-DD'),
      search: false,
    },
    {
      title: '合同报价',
      dataIndex: 'quotation',
      search: false,
    },
    {
      title: '已收款',
      dataIndex: 'receivedMoney',
      search: false,
    },
    {
      title: '已开票额',
      dataIndex: 'invoicedMoney',
      search: false,
    },
    {
      title: '阶段名称',
      dataIndex: 'stageName',
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'status',
    },
  ]
  const actionRef = useRef()
  return (
    <List
      actionRef={actionRef}
      rowKey="projectId"
      onEdit={(record) => navigate(`/project/edit?id=${record.projectId}`)}
      onDelete={(record) =>
        deleteTaProject(record.projectId).then(() => actionRef.current.reload())
      }
      toolBarRender={() => [
        <Button
          key="1"
          type="primary"
          onClick={() => {
            navigate('/project/edit')
          }}
        >
          新增
        </Button>,
      ]}
      request={getTaProject}
      columns={columns}
    />
  )
}
